Class: DesignSystem::Generic::Builders::ActionLink

Inherits:
Base
  • Object
show all
Defined in:
lib/design_system/generic/builders/action_link.rb

Overview

This class provides generic methods to display action links, which should be used to signpost the start of a digital service.

Instance Method Summary collapse

Methods inherited from Base

#initialize

Methods included from Helpers::CssHelper

#css_class_options_merge

Methods included from Concerns::BrandDerivable

#brand

Constructor Details

This class inherits a constructor from DesignSystem::Generic::Builders::Base

Instance Method Details



8
9
10
11
12
13
# File 'lib/design_system/generic/builders/action_link.rb', line 8

def render_action_link(name = nil, options = nil, html_options = nil)
  options ||= {}
  html_options ||= {}

  prep_style(name, options, html_options)
end