Class: DesignSystem::Generic::Builders::ActionLink
- Defined in:
- lib/design_system/generic/builders/action_link.rb
Overview
This class provides generic methods to display action links, which should be used to signpost the start of a digital service.
Direct Known Subclasses
DesignSystem::Govuk::Builders::ActionLink, Nhsuk::Builders::ActionLink
Instance Method Summary collapse
Methods inherited from Base
Methods included from Helpers::CssHelper
Methods included from Concerns::BrandDerivable
Constructor Details
This class inherits a constructor from DesignSystem::Generic::Builders::Base
Instance Method Details
#render_action_link(name = nil, options = nil, html_options = nil) ⇒ Object
8 9 10 11 12 13 |
# File 'lib/design_system/generic/builders/action_link.rb', line 8 def render_action_link(name = nil, = nil, = nil) ||= {} ||= {} prep_style(name, , ) end |