Module: DesignSystem::Generic::Builders::Elements::LeadParagraph
- Included in:
- FixedElements
- Defined in:
- lib/design_system/generic/builders/elements/lead_paragraph.rb
Overview
This mixin module is used to provide lead paragraphs.
Instance Method Summary collapse
Instance Method Details
#lead_paragraph(text = nil) ⇒ Object
9 10 11 12 13 |
# File 'lib/design_system/generic/builders/elements/lead_paragraph.rb', line 9 def lead_paragraph(text = nil, &) raise ArgumentError, 'Lead paragraph can only be used once per page' if @lead_paragraph @lead_paragraph = block_given? ? capture(&) : text end |